@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.22 2003/04/25 15:27:32 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.25 2003/07/08 15:17:08 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -1267,7 +1267,7 @@ push_num(int *MPval)        /* Try to push value onto the numeric stack. */
     if (v->numsptr >= MAXSTACK) {
         STRCPY(v->display, _("Numeric stack error"));
         set_display(v->display);
-        v->error = 1;
+        set_error_state(TRUE);
         beep();
     } else {
         if (v->MPnumstack[v->numsptr] == NULL) {
@@ -1288,7 +1288,7 @@ push_op(int val)     /* Try to push value onto the operand stack. */
     if (v->opsptr >= MAXSTACK) {
         STRCPY(v->display, _("Operand stack error"));
         set_display(v->display);
-        v->error = 1;
+        set_error_state(TRUE);
     } else {
         v->opstack[v->opsptr++] = val;
     }
